<?php
/**
 * Define some custom classes for uncode.
 * 
 * https://codex.wordpress.org/Class_Reference/WP_Customize_Control
 *
 * @package AccessPress Themes
 * @subpackage Uncode Lite
 * @since 1.0.0
 */

if ( class_exists( 'WP_Customize_Control' ) ) {

	/**
     * Switch button customize control.
     *
     * @since 1.0.0
     * @access public
     */
    class Uncode_Lite_Customize_Switch_Control extends WP_Customize_Control {

    	/**
	     * The type of customize control being rendered.
	     *
	     * @since  1.0.0
	     * @access public
	     * @var    string
	     */
		public $type = 'switch';
		/**
	     * Displays the control content.
	     *
	     * @since  1.0.0
	     * @access public
	     * @return void
	     */
		public function render_content() { ?>
			<label>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<div class="description customize-control-description"><?php echo esc_html( $this->description ); ?></div>
		        <div class="switch_options">
		        	<?php 
		        		$show_choices = $this->choices;
		        		foreach ( $show_choices as $key => $value ) {
		        			echo '<span class="switch_part '.esc_attr($key).'" data-switch="'.esc_attr($key).'">'. esc_attr($value).'</span>';
		        		}
		        	?>
                  	<input type="hidden" id="ap_switch_option" <?php $this->link(); ?> value="<?php echo esc_attr($this->value()); ?>" />
                </div>
            </label>
	<?php
		}
	}

	/**
	 * A class to create a dropdown for all categories in your wordpress site
	 *
	 * @since 1.0.0
	 * @access public
	 */
	class Uncode_Lite_Customize_Category_Control extends WP_Customize_Control {
		
		/**
		 * Render the control's content.
		 *
		 * @return HTML
		 * @since 1.0.0
		 */
		public function render_content() {
			$dropdown = wp_dropdown_categories(
				array(
					'name'              => '_customize-dropdown-categories-' . $this->id,
					'echo'              => 0,
					'show_option_none'  => esc_html__( '--Select Category--', 'uncode-lite' ),
					'option_none_value' => '0',
					'selected'          => $this->value(),
				)
			);

			// Hackily add in the data link parameter.
			$dropdown = str_replace( '<select', '<select ' . $this->get_link(), $dropdown );

			printf(
				'<label class="customize-control-select"><span class="customize-control-title">%s</span><span class="description customize-control-description">%s</span> %s </label>',
				esc_html($this->label),
				esc_html($this->description),
				$dropdown
			);
		}
	}
	

	/**
	 * A class to create a list of icons in customizer field
	 *
	 * @since 1.0.0
	 * @access public
	 */
	class Uncode_Lite_Customize_Icons_Control extends WP_Customize_Control {

		/**
	     * The type of customize control being rendered.
	     *
	     * @since  1.0.0
	     * @access public
	     * @var    string
	     */
		public $type = 'uncode_lite_icons';

		/**
	     * Displays the control content.
	     *
	     * @since  1.0.0
	     * @access public
	     * @return void
	     */
		public function render_content() {

			$saved_icon_value = $this->value(); ?>
			<label>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<span class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
				<div class="ap-customize-icons">
					<div class="selected-icon-preview"><?php if( !empty( $saved_icon_value ) ) { echo '<i class="fa '. esc_attr($saved_icon_value) .'"></i>'; } ?></div>
					<ul class="icons-list-wrapper">
						<?php 
							$uncode_lite_icons_list = uncode_lite_icons_array();
							foreach ( $uncode_lite_icons_list as $key => $icon_value ) {
								if( $saved_icon_value == $icon_value ) {
									echo '<li class="selected"><i class="fa '. esc_attr($icon_value) .'"></i></li>';
								} else {
									echo '<li><i class="fa '. esc_attr($icon_value) .'"></i></li>';
								}
							}
						?>
					</ul>
					<input type="hidden" class="ap-icon-value" value="" <?php $this->link(); ?>>
				</div>

			</label>
	<?php
		}
	}

	/**
	* Multiple checkbox customize control class.
	*
	* @since  1.0.0
	* @access public
	*/
	class Uncode_Lite_Customize_Control_Checkbox_Multiple extends WP_Customize_Control {

	   /**
	    * The type of customize control being rendered.
	    *
	    * @since  1.0.0
	    * @access public
	    * @var    string
	    */
	   public $type = 'checkbox-multiple';

	   /**
	    * Displays the control content.
	    *
	    * @since  1.0.0
	    * @access public
	    * @return void
	    */
	   public function render_content() {

	       if ( empty( $this->choices ) )
	           return; ?>

	       <?php if ( !empty( $this->label ) ) : ?>
	           <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
	       <?php endif; ?>

	       <?php if ( !empty( $this->description ) ) : ?>
	           <span class="description customize-control-description"><?php echo esc_html($this->description); ?></span>
	       <?php endif; ?>

	       <?php $multi_values = !is_array( $this->value() ) ? explode( ',', $this->value() ) : $this->value(); ?>

	       <ul>
	           <?php foreach ( $this->choices as $value => $label ) : ?>

	               <li>
	                   <label>
	                       <input type="checkbox" value="<?php echo esc_attr( $value ); ?>" <?php checked( in_array( $value, $multi_values ) ); ?> /> 
	                       <?php echo esc_html( $label ); ?>
	                   </label>
	               </li>

	           <?php endforeach; ?>
	       </ul>

	       <input type="hidden" <?php $this->link(); ?> value="<?php echo esc_attr( implode( ',', $multi_values ) ); ?>" />
	   <?php }
	}

	/**
	 * A class to create a option separator in customizer section 
	 *
	 *@since 1.0.0
	 */
	class uncode_lite_Customize_Section_Separator extends WP_Customize_Control {

		public $type = 'uncode_lite_separator';

		public function render_content() { ?>
			<div class="serviceswrap">
				<label>
					<span class="sep-title"><?php echo esc_html( $this->label ); ?></span>
				</label>
			</div>
	    <?php }
	}

    /**
     * Pro customizer section.
     *
     * @since  1.0.0
     * @access public
     */
    class Uncode_Customize_Section_Pro extends WP_Customize_Section {

        /**
         * The type of customize section being rendered.
         *
         * @since  1.0.0
         * @access public
         * @var    string
         */
        public $type = 'uncode-pro';

        /**
         * Custom button text to output.
         *
         * @since  1.0.0
         * @access public
         * @var    string
         */
        public $title1 = '';
        public $pro_text1 = '';

        /**
         * Custom pro button URL.
         *
         * @since  1.0.0
         * @access public
         * @var    string
         */
        public $pro_url1 = '';

        /**
         * Add custom parameters to pass to the JS via JSON.
         *
         * @since  1.0.0
         * @access public
         * @return void
         */
        public function json() {
            $json = parent::json();
            $json['title1'] = $this->title1;
            $json['pro_text1'] = $this->pro_text1;
            $json['pro_url1']  = $this->pro_url1;
            return $json;
        }

        /**
         * Outputs the Underscore.js template.
         *
         * @since  1.0.0
         * @access public
         * @return void
         */
        protected function render_template() { ?>

            <li id="accordion-section-{{ data.id }}" class="accordion-section control-section control-section-{{ data.type }} cannot-expand">
                <h3 class="accordion-section-title">
                    {{ data.title1 }}
                    <# if ( data.pro_text1 && data.pro_url1 ) { #>
                        <a href="{{ data.pro_url1 }}" class="button button-secondary alignright" target="_blank">{{ data.pro_text1 }}</a>
                    <# } #>
                </h3>
            </li>
        <?php }
    }

    /**
     * Switch button customize control.
     *
     * @since 1.0.0
     * @access public
     */
    class Uncode_Lite_Customize_Moreinfos_Control extends WP_Customize_Control {

    	/**
	     * The type of customize control being rendered.
	     *
	     * @since  1.0.0
	     * @access public
	     * @var    string
	     */
		//public $type = 'switch';
		/**
	     * Displays the control content.
	     *
	     * @since  1.0.0
	     * @access public
	     * @return void
	     */
		public function render_content() { ?>
			<label>
				<p><i><?php echo wp_kses_post($this->label); ?></i></p>
            </label>
	<?php
		}
	}

	class enlighten_fa_icon extends WP_Customize_Control {
      
      public $type = 'faselect';
        /**
         * Render the content of the category dropdown
         *
         * @return HTML
         */
        public function render_content() {
            ?><label>
                    <?php if ( ! empty( $this->label ) ) : ?>
    				    <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
                        <div class="fa_preview"><i id="fa_prev" class="fa <?php echo esc_attr( $this->value() ); ?>"></i>
                    <?php endif; ?>
                    <ul class="ap-font-group">
                        <li><i class="fa fa-glass"></i></li>
                        <li><i class="fa fa-music"></i> </li>
                        <li><i class="fa fa-search"></i></li>
                        <li><i class="fa fa-envelope-o"></i> </li>
                        <li><i class="fa fa-heart"></i></li>
                        <li><i class="fa fa-star"></i></li>
                        <li><i class="fa fa-star-o"></i></li>
                        <li><i class="fa fa-user"></i> </li>
                        <li><i class="fa fa-film"></i> </li>
                        <li><i class="fa fa-th-large"></i> </li>
                        <li><i class="fa fa-th"></i> </li>
                        <li><i class="fa fa-th-list"></i> </li>
                        <li><i class="fa fa-check"></i> </li>
                        <li><i class="fa fa-times"></i></li>
                        <li><i class="fa fa-search-plus"></i></li>
                        <li><i class="fa fa-search-minus"></i></li>
                        <li><i class="fa fa-power-off"></i> </li>
                        <li><i class="fa fa-signal"></i> </li>
                        <li><i class="fa fa-cog"></i></li>
                        <li><i class="fa fa-trash-o"></i></li>
                        <li><i class="fa fa-home"></i></li>
                        <li><i class="fa fa-file-o"></i> </li>
                        <li><i class="fa fa-clock-o"></i> </li>
                        <li><i class="fa fa-road"></i> </li>
                        <li><i class="fa fa-download"></i></li>
                        <li><i class="fa fa-arrow-circle-o-down"></i></li>
                        <li><i class="fa fa-arrow-circle-o-up"></i> </li>
                        <li><i class="fa fa-inbox"></i></li>
                        <li><i class="fa fa-play-circle-o"></i> </li>
                        <li><i class="fa fa-repeat"></i> </li>
                        <li><i class="fa fa-refresh"></i> </li>
                        <li><i class="fa fa-list-alt"></i> </li>
                        <li><i class="fa fa-lock"></i> </li>
                        <li><i class="fa fa-flag"></i> </li>
                        <li><i class="fa fa-headphones"></i> </li>
                        <li><i class="fa fa-volume-off"></i> </li>
                        <li><i class="fa fa-volume-down"></i> </li>
                        <li><i class="fa fa-volume-up"></i> </li>
                        <li><i class="fa fa-qrcode"></i></li>
                        <li><i class="fa fa-barcode"></i></li>
                        <li><i class="fa fa-tag"></i> </li>
                        <li><i class="fa fa-tags"></i> </li>
                        <li><i class="fa fa-book"></i> </li>
                        <li><i class="fa fa-bookmark"></i></li>
                        <li><i class="fa fa-print"></i> </li>
                        <li><i class="fa fa-camera"></i> </li>
                        <li><i class="fa fa-font"></i> </li>
                        <li><i class="fa fa-bold"></i> </li>
                        <li><i class="fa fa-italic"></i> </li>
                        <li><i class="fa fa-text-height"></i> </li>
                        <li><i class="fa fa-text-width"></i></li>
                        <li><i class="fa fa-align-left"></i> </li>
                        <li><i class="fa fa-align-center"></i></li>
                        <li><i class="fa fa-align-right"></i> </li>
                        <li><i class="fa fa-align-justify"></i></li>
                        <li><i class="fa fa-list"></i></li>
                        <li><i class="fa fa-outdent"></i></li>
                        <li><i class="fa fa-indent"></i></li>
                        <li><i class="fa fa-video-camera"></i> </li>
                        <li><i class="fa fa-picture-o"></i></li>
                        <li><i class="fa fa-pencil"></i> </li>
                        <li><i class="fa fa-map-marker"></i> </li>
                        <li><i class="fa fa-adjust"></i> </li>
                        <li><i class="fa fa-tint"></i> </li>
                        <li><i class="fa fa-pencil-square-o"></i></li>
                        <li><i class="fa fa-share-square-o"></i> </li>
                        <li><i class="fa fa-check-square-o"></i> </li>
                        <li><i class="fa fa-arrows"></i> </li>
                        <li><i class="fa fa-step-backward"></i> </li>
                        <li><i class="fa fa-fast-backward"></i></li>
                        <li><i class="fa fa-backward"></i> </li>
                        <li><i class="fa fa-play"></i></li>
                        <li><i class="fa fa-pause"></i> </li>
                        <li><i class="fa fa-stop"></i> </li>
                        <li><i class="fa fa-forward"></i> </li>
                        <li><i class="fa fa-fast-forward"></i> </li>
                        <li><i class="fa fa-step-forward"></i></li>
                        <li><i class="fa fa-eject"></i> </li>
                        <li><i class="fa fa-chevron-left"></i> </li>
                        <li><i class="fa fa-chevron-right"></i> </li>
                        <li><i class="fa fa-plus-circle"></i></li>
                        <li><i class="fa fa-minus-circle"></i></li>
                        <li><i class="fa fa-times-circle"></i> </li>
                        <li><i class="fa fa-check-circle"></i> </li>
                        <li><i class="fa fa-question-circle"></i></li> 
                        <li><i class="fa fa-info-circle"></i> </li>
                        <li><i class="fa fa-crosshairs"></i></li>
                        <li><i class="fa fa-times-circle-o"></i> </li>
                        <li><i class="fa fa-check-circle-o"></i> </li>
                        <li><i class="fa fa-ban"></i> </li>
                        <li><i class="fa fa-arrow-left"></i> </li>
                        <li><i class="fa fa-arrow-right"></i> </li>
                        <li><i class="fa fa-arrow-up"></i></li> 
                        <li><i class="fa fa-arrow-down"></i> </li>
                        <li><i class="fa fa-share"></i> </li>
                        <li><i class="fa fa-expand"></i> </li>
                        <li><i class="fa fa-compress"></i> </li>
                        <li><i class="fa fa-plus"></i> </li>
                        <li><i class="fa fa-minus"></i></li>
                        <li><i class="fa fa-asterisk"></i></li>
                        <li><i class="fa fa-exclamation-circle"></i> </li>
                        <li><i class="fa fa-gift"></i> </li>
                        <li><i class="fa fa-leaf"></i> </li>
                        <li><i class="fa fa-fire"></i> </li>
                        <li><i class="fa fa-eye"></i> </li>
                        <li><i class="fa fa-eye-slash"></i> </li>
                        <li><i class="fa fa-exclamation-triangle"></i> </li>
                        <li><i class="fa fa-plane"></i> </li>
                        <li><i class="fa fa-calendar"></i> </li>
                        <li><i class="fa fa-random"></i></li>
                        <li><i class="fa fa-comment"></i> </li>
                        <li><i class="fa fa-magnet"></i></li>
                        <li><i class="fa fa-chevron-up"></i> </li>
                        <li><i class="fa fa-chevron-down"></i> </li>
                        <li><i class="fa fa-retweet"></i> </li>
                        <li><i class="fa fa-shopping-cart"></i> </li>
                        <li><i class="fa fa-folder"></i> </li>
                        <li><i class="fa fa-folder-open"></i> </li>
                        <li><i class="fa fa-arrows-v"></i> </li>
                        <li><i class="fa fa-arrows-h"></i> </li>
                        <li><i class="fa fa-bar-chart"></i></li>
                        <li><i class="fa fa-twitter-square"></i> </li>
                        <li><i class="fa fa-facebook-square"></i> </li>
                        <li><i class="fa fa-camera-retro"></i> </li>
                        <li><i class="fa fa-key"></i> </li>
                        <li><i class="fa fa-cogs"></i> </li>
                        <li><i class="fa fa-comments"></i> </li>
                        <li><i class="fa fa-thumbs-o-up"></i> </li>
                        <li><i class="fa fa-thumbs-o-down"></i> </li>
                        <li><i class="fa fa-star-half"></i></li>
                        <li><i class="fa fa-heart-o"></i></li>
                        <li><i class="fa fa-sign-out"></i></li>
                        <li><i class="fa fa-linkedin-square"></i> </li>
                        <li><i class="fa fa-thumb-tack"></i> </li>
                        <li><i class="fa fa-external-link"></i></li>
                        <li><i class="fa fa-sign-in"></i> </li>
                        <li><i class="fa fa-trophy"></i></li>
                        <li><i class="fa fa-github-square"></i></li>
                        <li><i class="fa fa-upload"></i> </li>
                        <li><i class="fa fa-lemon-o"></i> </li>
                        <li><i class="fa fa-phone"></i> </li>
                        <li><i class="fa fa-square-o"></i> </li>
                        <li><i class="fa fa-bookmark-o"></i> </li>
                        <li><i class="fa fa-phone-square"></i> </li>
                        <li><i class="fa fa-twitter"></i> </li>
                        <li><i class="fa fa-facebook"></i></li>
                        <li><i class="fa fa-github"></i> </li>
                        <li><i class="fa fa-unlock"></i> </li>
                        <li><i class="fa fa-credit-card"></i> </li>
                        <li><i class="fa fa-rss"></i></li>
                        <li><i class="fa fa-hdd-o"></i> </li>
                        <li><i class="fa fa-bullhorn"></i> </li>
                        <li><i class="fa fa-bell"></i></li>
                        <li><i class="fa fa-certificate"></i> </li>
                        <li><i class="fa fa-hand-o-right"></i> </li>
                        <li><i class="fa fa-hand-o-left"></i> </li>
                        <li><i class="fa fa-hand-o-up"></i></li>
                        <li><i class="fa fa-hand-o-down"></i></li>
                        <li><i class="fa fa-arrow-circle-left"></i></li>
                        <li><i class="fa fa-arrow-circle-right"></i> </li>
                        <li><i class="fa fa-arrow-circle-up"></i> </li>
                        <li><i class="fa fa-arrow-circle-down"></i> </li>
                        <li><i class="fa fa-globe"></i></li>
                        <li><i class="fa fa-wrench"></i> </li>
                        <li><i class="fa fa-tasks"></i> </li>
                        <li><i class="fa fa-filter"></i> </li>
                        <li><i class="fa fa-briefcase"></i></li>
                        <li><i class="fa fa-arrows-alt"></i></li>
                        <li><i class="fa fa-users"></i></li>
                        <li><i class="fa fa-link"></i></li>
                        <li><i class="fa fa-cloud"></i> </li>
                        <li><i class="fa fa-flask"></i> </li>
                        <li><i class="fa fa-scissors"></i></li>
                        <li><i class="fa fa-files-o"></i></li>
                        <li><i class="fa fa-paperclip"></i></li>
                        <li><i class="fa fa-floppy-o"></i></li>
                        <li><i class="fa fa-square"></i></li>
                        <li><i class="fa fa-bars"></i></li>
                        <li><i class="fa fa-list-ul"></i> </li>
                        <li><i class="fa fa-list-ol"></i> </li>
                        <li><i class="fa fa-strikethrough"></i> </li>
                        <li><i class="fa fa-underline"></i></li>
                        <li><i class="fa fa-table"></i> </li>
                        <li><i class="fa fa-magic"></i> </li>
                        <li><i class="fa fa-truck"></i> </li>
                        <li><i class="fa fa-pinterest"></i> </li>
                        <li><i class="fa fa-pinterest-square"></i></li>
                        <li><i class="fa fa-google-plus-square"></i></li>
                        <li><i class="fa fa-google-plus"></i> </li>
                        <li><i class="fa fa-money"></i> </li>
                        <li><i class="fa fa-caret-down"></i> </li>
                        <li><i class="fa fa-caret-up"></i></li>
                        <li><i class="fa fa-caret-left"></i></li>
                        <li><i class="fa fa-caret-right"></i> </li>
                        <li><i class="fa fa-columns"></i></li>
                        <li><i class="fa fa-sort"></i> </li>
                        <li><i class="fa fa-sort-desc"></i> </li>
                        <li><i class="fa fa-sort-asc"></i> </li>
                        <li><i class="fa fa-envelope"></i> </li>
                        <li><i class="fa fa-linkedin"></i> </li>
                        <li><i class="fa fa-undo"></i> </li>
                        <li><i class="fa fa-gavel"></i> </li>
                        <li><i class="fa fa-tachometer"></i></li>
                        <li><i class="fa fa-comment-o"></i> </li>
                        <li><i class="fa fa-comments-o"></i> </li>
                        <li><i class="fa fa-bolt"></i></li>
                        <li><i class="fa fa-sitemap"></i> </li>
                        <li><i class="fa fa-umbrella"></i> </li>
                        <li><i class="fa fa-clipboard"></i> </li>
                        <li><i class="fa fa-lightbulb-o"></i> </li>
                        <li><i class="fa fa-exchange"></i> </li>
                        <li><i class="fa fa-cloud-download"></i> </li>
                        <li><i class="fa fa-cloud-upload"></i> </li>
                        <li><i class="fa fa-user-md"></i></li>
                        <li><i class="fa fa-stethoscope"></i> </li>
                        <li><i class="fa fa-suitcase"></i></li>
                        <li><i class="fa fa-bell-o"></i></li>
                        <li><i class="fa fa-coffee"></i> </li>
                        <li><i class="fa fa-cutlery"></i> </li>
                        <li><i class="fa fa-file-text-o"></i></li>
                        <li><i class="fa fa-building-o"></i></li>
                        <li><i class="fa fa-hospital-o"></i> </li>
                        <li><i class="fa fa-ambulance"></i> </li>
                        <li><i class="fa fa-medkit"></i></li>
                        <li><i class="fa fa-fighter-jet"></i> </li>
                        <li><i class="fa fa-beer"></i> </li>
                        <li><i class="fa fa-h-square"></i></li> 
                        <li><i class="fa fa-plus-square"></i> </li>
                        <li><i class="fa fa-angle-double-left"></i> </li>
                        <li><i class="fa fa-angle-double-right"></i> </li>
                    </ul>
                    </div>
                    <input type="hidden" <?php $this->input_attrs(); ?> value="<?php echo esc_attr( $this->value() ); ?>" <?php $this->link(); ?> />
    			</label>
        <?php
    }
  }
}
